#
# spec file for package OpenShadingLanguage
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The library soname versions follow the package version major and minor numbers.
%define sover %(echo %{version} | cut -d . -f 1,2)
%define sufx %(echo %{sover}|tr . _)
# Required for the plugin directory name, see https://github.com/OpenImageIO/oiio/issues/2583
%define oiio_major_minor_ver %(rpm -q --queryformat='%%{version}' OpenImageIO-devel | cut -d . -f 1-2)

Name:           OpenShadingLanguage
Version:        1.11.12.0
Release:        bp153.1.1
Summary:        A language for programmable shading
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
URL:            https://github.com/imageworks/OpenShadingLanguage
Source0:        https://github.com/imageworks/OpenShadingLanguage/archive/Release-%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://creativecommons.org/licenses/by/3.0/legalcode.txt#/CC-BY-3.0.txt
BuildRequires:  OpenEXR-devel
BuildRequires:  bison
BuildRequires:  clang-devel >= 7
BuildRequires:  cmake >= 3.12
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  pkg-config
BuildRequires:  python3-devel
BuildRequires:  python3-pybind11-devel
BuildRequires:  cmake(OpenImageIO) >= 2.0
BuildRequires:  cmake(pugixml)
Requires:       %{name}-common-headers = %{version}
Recommends:     %{name}-doc = %{version}

%description
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

This package contains the standalone oslc compiler and some
utilities.

%package doc
Summary:        Documentation for OpenShadingLanguage
License:        CC-BY-3.0
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.
This package contains documentation.

%package MaterialX-shaders-source
Summary:        MaterialX shader nodes
License:        BSD-3-Clause
Group:          Development/Languages/Other
Requires:       %{name} = %{version}
Requires:       %{name}-common-headers

%description MaterialX-shaders-source
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

This package contains the code for the MaterialX shader nodes.

%package example-shaders-source
Summary:        OSL shader examples
License:        BSD-3-Clause
Group:          Development/Languages/Other
Requires:       %{name} = %{version}
Requires:       %{name}-common-headers

%description example-shaders-source
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

This package contains some OSL example shaders.

%package common-headers
Summary:        OSL standard library and auxiliary headers
License:        BSD-3-Clause
Group:          Development/Languages/Other
Requires:       %{name} = %{version}

%description common-headers
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

This package contains the OSL standard library headers, as well
as some additional headers useful for writing shaders.

%package -n liboslcomp%{sufx}
Summary:        OpenShadingLanguage's compiler component library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n liboslcomp%{sufx}
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

%package -n liboslexec%{sufx}
Summary:        OpenShadingLanguage's execution component library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n liboslexec%{sufx}
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

%package -n liboslnoise%{sufx}
Summary:        OpenShadingLanguage's image noise generation library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n liboslnoise%{sufx}
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

%package -n liboslquery%{sufx}
Summary:        Osl library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n liboslquery%{sufx}
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

%package -n libtestshade%{sufx}
Summary:        Osl library
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libtestshade%{sufx}
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

%package -n OpenImageIO-plugin-osl
Summary:        OpenImageIO input plugin
License:        BSD-3-Clause
Group:          System/Libraries
Obsoletes:      osl.imageio < 1.11.4.1
Provides:       osl.imageio = %{version}

%description -n OpenImageIO-plugin-osl
Open Shading Language (OSL) is a language for programmable shading
in advanced renderers and other applications, ideal for describing
materials, lights, displacement, and pattern generation.

This is a plugin to access OSL from OpenImageIO.

%package        devel
Summary:        Development files for %{name}
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       liboslcomp%{sufx} = %{version}
Requires:       liboslexec%{sufx} = %{version}
Requires:       liboslnoise%{sufx} = %{version}
Requires:       liboslquery%{sufx} = %{version}
Requires:       libtestshade%{sufx} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{name}-Release-%{version}
find . -iname CMakeLists.txt -exec sed "-i" "-e s/COMMAND python/COMMAND python3/" "{}" \;

%build
%define _lto_cflags %{nil}
%cmake \
      -DCMAKE_SKIP_RPATH:BOOL=TRUE \
      -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name} \
      -DOSL_SHADER_INSTALL_DIR:PATH=%{_datadir}/%{name}/shaders/ \
      -DOSL_BUILD_MATERIALX:BOOL=ON \
      -DCMAKE_CXX_STANDARD:STRING=14
%cmake_build

%install
%cmake_install
# Add Creative Commons license for documentation
cp -v %{SOURCE1} .
# Move the OpenImageIO plugin into its default search path
mkdir %{buildroot}%{_libdir}/OpenImageIO-%{oiio_major_minor_ver}
mv %{buildroot}%{_libdir}/osl.imageio.so %{buildroot}%{_libdir}/OpenImageIO-%{oiio_major_minor_ver}/

find %{buildroot} -name LICENSE.md -print -delete
# add top level markdowns to the doc package
cp -p *.md %{buildroot}%{_docdir}/%{name}/
# TODO: package python module
find %{buildroot}%{python3_sitearch} -name oslquery.so -print -delete

%post -n liboslcomp%{sufx} -p /sbin/ldconfig
%postun -n liboslcomp%{sufx} -p /sbin/ldconfig

%post -n liboslexec%{sufx} -p /sbin/ldconfig
%postun -n liboslexec%{sufx} -p /sbin/ldconfig

%post -n liboslnoise%{sufx} -p /sbin/ldconfig
%postun -n liboslnoise%{sufx} -p /sbin/ldconfig

%post -n liboslquery%{sufx} -p /sbin/ldconfig
%postun -n liboslquery%{sufx} -p /sbin/ldconfig

%post -n libtestshade%{sufx} -p /sbin/ldconfig
%postun -n libtestshade%{sufx} -p /sbin/ldconfig

%files
%license LICENSE.md
%{_bindir}/*

%files doc
%license CC-BY-3.0.txt
%doc %{_docdir}/%{name}/

%files MaterialX-shaders-source
%{_datadir}/%{name}/shaders/MaterialX

%files example-shaders-source
%{_datadir}/%{name}/shaders/*.osl
%{_datadir}/%{name}/shaders/*.oso

%files common-headers
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/shaders
%{_datadir}/%{name}/shaders/*.h

%files -n liboslcomp%{sufx}
%license LICENSE.md
%{_libdir}/liboslcomp.so.%{sover}*

%files -n liboslexec%{sufx}
%license LICENSE.md
%{_libdir}/liboslexec.so.%{sover}*

%files -n liboslnoise%{sufx}
%license LICENSE.md
%{_libdir}/liboslnoise.so.%{sover}*

%files -n liboslquery%{sufx}
%license LICENSE.md
%{_libdir}/liboslquery.so.%{sover}*

%files -n libtestshade%{sufx}
%license LICENSE.md
%{_libdir}/libtestshade.so.%{sover}*

%files -n OpenImageIO-plugin-osl
%license LICENSE.md
%{_libdir}/OpenImageIO-%{oiio_major_minor_ver}/osl.imageio.so

%files devel
%license LICENSE.md
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/cmake/OSL
%{_libdir}/pkgconfig/osl*.pc

%changelog
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- do not list pkgconfig directory - provided by filesystem package
* Sun Mar 21 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 1.11.12
  + Build: Changes for smooth compile against upcoming Imath 3.0.
    [#1332] #1341
  + Build: We weren't properly hiding non-public symbols. #1337
  + CI: Cleanup and get rid of the last Travis vestiges. #1334
  + CI: Speed up CI runs by using GHA cache + ccache. #1335
  + CI: Separate CI process into several individual "steps." #1338
- Update to version 1.11.11
  + Build: Make the CMake build system more friendly to being a
    subproject.
  + #1304
  + Build: Improve dependency on Imath/OpenEXR include files.
  + CI: Fixes to Mac CI. #1315
  + Docs: Update CLAs, Charter, GOVERNANCE, particularly after
    acceptance of
  + new CLAs and moving the repo to the ASWF GitHub account. #1308
    [#1240] #1314
  + Internals: Switch from deprecated call to OIIO::parallel_image
    to the new
  + version. #1317
- Update to version 1.11.10
  + Bug fix: optimizer interaction with output param that also is
    userdata.
  + #1295
  + Ensure that LoadMemoryCompiledShader returns false upon parse
    failure.
  + #1302
  + Work to ensure that OIIO will build correctly against the
    upcoming
  + Imath 3.0 and OpenEXR 3.0. #1299
- Disable lto
* Sat Nov  7 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to v1.11.9.0, see included CHANGES.md or
  https://github.com/imageworks/OpenShadingLanguage/blob/Release-1.11.9.0/CHANGES.md
- Add new build dependency python3-pybind11
- Remove stray python3 oslquery module
- Add loplevel markdown documents to doc package
* Tue Jul 28 2020 Hans-Peter Jansen <hpj@urpla.net>
- disable RPATH handling - fixes 15.1 build
* Sun Jul  5 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to v1.11.6.0, see included CHANGES.md or
  https://github.com/imageworks/OpenShadingLanguage/blob/Release-1.11.6.0-dev/CHANGES.md
- Drop obsolete patches:
  + 0001-Fix-typo-in-the-.pc.in-files-that-botched-the-versio.patch
  + 0001-LLVM-10-odds-and-ends-1135.patch
  + 0001-Some-SPI-build-fixes-for-finding-the-right-llvm.patch
  + 0001-Use-single-shared-clang-cpp-library-starting-with-LL.patch
- Renamed legalcode.txt to CC-BY-3.0.txt
* Wed May 13 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use the correct CMake variable to set the shader install location.
- Replace osl-pkgconfig-versions.patch with correct upstream
  0001-Fix-typo-in-the-.pc.in-files-that-botched-the-versio.patch
- Adapt to LLVM 9/10 changes defaulting to single clang-cpp library,
  add 0001-Use-single-shared-clang-cpp-library-starting-with-LL.patch
  instead of mangling CMake output.
- Dropped osl-oslimageio-soname.patch, which erroneously adds a
  version to the OpenImageIO plugin, voiding any chance for
  OIIO to find and load the plugin.
- Rename the osl.imageio package to OpenImageIO-plugin-osl, to
  better reflect its purpose, install the plugin to the default
  OpenImageIO plugin directory.
- Use python3 for the build process.
* Tue Apr 21 2020 Dave Plater <davejplater@gmail.com>
- Update to v1.11.4.1 to fix build with LLVM10.
- Remove incorporated patch:
  0001-Generalize-lookup-of-stdosl.h-in-install-directory-a.patch
- Added patches from git:
  0001-Some-SPI-build-fixes-for-finding-the-right-llvm.patch and
  0001-LLVM-10-odds-and-ends-1135.patch.
- Created osl-pkgconfig-versions.patch to fix pc file's version
  fields. Upstreamed along with workaround for new libclang-cpp in
  issue #1155
- Created osl-oslimageio-soname.patch to keep the library build in
  line with v1.x.
- For many upstream changes since v1.10.7 see:
  /usr/share/doc/packages/OpenShadingLanguage/CHANGES.md
* Wed Nov  6 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Properly rebase 0001-Generalize-lookup-of-stdosl.h-in-install-directory-a.patch
  avoid workarounds in the spec file.
- Remove conditional code for Leap 42.x
- Reflect required versions of OpenIIO and Clang in the spec file.
* Wed Nov  6 2019 Dave Plater <davejplater@gmail.com>
- Update to release 1.10.7 which fixes build with new llvm.
- Rebased:
  0001-Generalize-lookup-of-stdosl.h-in-install-directory-a.patch
- Recent upstream changes:
  * Adjust for deprecated material in more recent Qt releases. #1043
  * Fixes for MinGW compiler. #1047
  * Texture "missingalpha" optional parameter generated incorrect
  code and crashed. #1044
  * Fix incorrect optimizations surrounding 'exit()' calls in the
  middle of certain shader code blocks. #1051
  * LLVM 9 / clang 9 compatibility. #1058
  * Fixes to Travis CI system to keep up with OIIO master recently
  upgrading its minimum required CMake. #1065
* Sun Jan 13 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix lookup of stdosl.h from oslc (bnc#1123254):
  Dropped OpenShadingLanguage-shaderinstalldir.patch
  Added 0001-Generalize-lookup-of-stdosl.h-in-install-directory-a.patch
- Cleaned up spec file (defattr)
- Correct LLVM_MCJIT_LIBRARY value, add comment
- Use current LLVM for building (bnc#1123252)
- Split shaders in common-headers, MaterialX-shaders and example-shaders
  subpackages. stdosl.h in common-headers is required by oslc in
  the main package (bnc#1123254).
- Correct clang-devel package name for Leap 42.3
* Tue Jan  8 2019 Jan Engelhardt <jengelh@inai.de>
- Spruce up descriptions a bit.
* Mon Dec 31 2018 davejplater@gmail.com
- Initial version 1.9.13 created for blender see boo#1120406
- Blender fails to build with 1.10.x versions
- Added OpenShadingLanguage-shaderinstalldir.patch shaders are
  installed directly under /usr see:
  https://github.com/imageworks/OpenShadingLanguage/issues/955
